{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "MACS2_cutoff",
            "doc": "Inflection point calculated from MACS2 peaks file",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/bioconductor-diffbind:2.16.0--r40h5f743cb_2",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "bioconductor-diffbind",
                            "version": [
                                "2.16.0"
                            ],
                            "specs": [
                                "https://anaconda.org/bioconda/bioconductor-diffbind"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "MACScutoff.R",
                            "entry": "args = commandArgs(trailingOnly=TRUE)\nlibrary(ggplot2)\npeak_cutoff_file = args[1]\nout_pdf = args[2]\nout_inflection = args[3]\ncutoff = read.table(peak_cutoff_file, header = T, sep = \"\\t\", stringsAsFactors = F, check.names = F)\ncutoff$lognpeak = log10(cutoff$npeaks)\ncutoff$index= 1:nrow(cutoff)\ncutoff$infl = predict(loess(cutoff$lognpeak ~ cutoff$index))\ncutoff$diff = c(0, diff(cutoff$infl))\ncutoff$diff2 = c(0, diff(cutoff$diff))\ncutoff$diff2[2] = 0\ninflpoint = cutoff[cutoff$diff2 == max(cutoff$diff2),][[1]]\np1 = ggplot(data=cutoff, aes(x=pscore, y=npeaks, group=1)) +\n    geom_line()+\n    geom_point() +\n    scale_y_continuous(trans='log2') +\n    geom_vline(xintercept = inflpoint, color = \"red\", linetype = \"dotted\") +\n    geom_smooth(method = 'loess') +\n    geom_line() +\n    ylab(\"log10(number of peaks)\") +\n    xlab(\"log10(p-value)\") +\n    theme_bw()\npdf(out_pdf)\nplot(p1)\ndev.off()\nwrite.table(10^-inflpoint, out_inflection, quote = F, row.names = F, col.names = F)\n"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#macs-cutoff.cwl/out_inflection_name"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#macs-cutoff.cwl/out_pdf_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#macs-cutoff.cwl/peak_cutoff_file"
                }
            ],
            "baseCommand": [
                "Rscript",
                "MACScutoff.R"
            ],
            "id": "#macs-cutoff.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_inflection_name)"
                    },
                    "id": "#macs-cutoff.cwl/out_inflection"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_pdf_name)"
                    },
                    "id": "#macs-cutoff.cwl/out_pdf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "readQC",
            "doc": "NGS read Quality Control analysis",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/bioconductor-diffbind:2.16.0--r40h5f743cb_2",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "bioconductor-diffbind",
                            "version": [
                                "2.16.0"
                            ],
                            "specs": [
                                "https://anaconda.org/bioconda/bioconductor-diffbind"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "readQC.R",
                            "entry": "args = commandArgs(trailingOnly=TRUE)\nlibrary(\"ggplot2\")\nlibrary(dplyr)\ntags=args[1]\nif(!dir.exists(tags)) {\n  stop(\"ERROR: Tag folder not found\")\n}\nsample_name = basename(tags)\n## Tag count uniqueness ##ss\ntcount = read.table(paste0(tags,\"/tagCountDistribution.txt\"), header = T, sep = \"\\t\")\ncolnames(tcount) = c(\"Alignments\", \"Fraction\")\ntcount = tcount[tcount[,1] <= 10,]\ntcount = tcount[tcount[,1] > 0,]\npdf(paste0(sample_name, \"_Uniqueness.pdf\"))\nggplot(data = tcount, aes(x=Alignments, y=Fraction)) +\n  geom_line(stat=\"identity\", linetype = \"dashed\") +\n  scale_y_continuous(limits = c(0,1)) +\n  scale_x_continuous(breaks = c(1:10)) +\n  xlab(\"No. secondary alignments\") +\n  theme_classic() +\n  geom_point()\ndev.off()\n## Peak size and FPKM stats END ##\n## Autocorrelation analysis ##\nacorr = read.table(paste0(tags,\"/tagAutocorrelation.txt\"), header = T, sep = \"\\t\")\ncolnames(acorr) = c(\"Distance\", \"Same_strand\", \"Opposite_strand\")\ndf = acorr\ndf[,3] = NULL\ncolnames(df) = c(\"Distance\", \"Total\")\ndf$type=\"Same strand\"\nacorr[,2] = NULL\ncolnames(acorr) = c(\"Distance\", \"Total\")\nacorr$type=\"Opposite strand\"\ndf = rbind(df, acorr)\ndistances = c(\"2000\", \"1000\", \"500\", \"250\", \"200\")\nfor(i in 1:length(distances)) {\n  df = df[df[,1] >= -as.numeric(distances[i]) & df[,1] <= as.numeric(distances[i]),]\n  pdf(paste0(sample_name,\"_Autocorrelation_\", distances[i], \"dist.pdf\"))\n  p1 = ggplot(data = df, aes(x=Distance, y=Total, group=type)) +\n    geom_line(aes(color=type)) +\n    theme_classic()\n  plot(p1)\n  dev.off()\n}\n## Autocorrelation analysis END ##\n## Tag length distro analysis ##\ntlen = read.table(paste0(tags,\"/tagLengthDistribution.txt\"), header = T, sep = \"\\t\")\ncolnames(tlen) = c(\"Length\", \"Fraction\")\ntlen$type=\"standard\"\ndf = tlen\ndf$Fraction = cumsum(df$Fraction)\ndf$type=\"cumulative\"\ndf = rbind(df, tlen)\npdf(paste0(sample_name, \"_Length_distribution.pdf\"))\nggplot(data = df, aes(x=Length, y=Fraction, group=type)) +\n  geom_line(aes(color=type)) +\n  geom_point(aes(color=type)) +\n  theme_classic()\ndev.off()\n## Tag length distro analysis END ##\n## GC content analysis ##\ngenomeGC = read.table(paste0(tags,\"/genomeGCcontent.txt\"), header = T, sep = \"\\t\")\nsampleGC = read.table(paste0(tags,\"/tagGCcontent.txt\"), header = T, sep = \"\\t\")\ncolnames(genomeGC) = c(\"GC\", \"Total\", \"Normalized\")\ncolnames(sampleGC) = c(\"GC\", \"Total\", \"Normalized\")\ngenomeGC$type=\"Genome\"\nsampleGC$type=\"Sample\"\ndf = rbind(genomeGC, sampleGC)\npdf(paste0(sample_name, \"_GC_content.pdf\"))\nggplot(data=df, aes(x=GC, y=Normalized, group=type)) +\n  geom_line(aes(color=type)) +\n  geom_point(aes(color=type)) +\n  theme_classic()\ndev.off()\n## GC content analysis end ##\n"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 512,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#readQC.cwl/tags_directory"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.pdf"
                    },
                    "id": "#readQC.cwl/plots"
                }
            ],
            "baseCommand": [
                "Rscript",
                "--vanilla",
                "readQC.R"
            ],
            "id": "#readQC.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "gzip",
            "doc": "Compress files",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:18.04",
                    "id": "#ubuntu-docker.yml"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-d"
                    },
                    "id": "#gzip.cwl/d"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#gzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.d){\n    return inputs.file.nameroot;\n  }else{\n    return inputs.file.basename + '.gz';\n  }\n}\n"
                    },
                    "id": "#gzip.cwl/output"
                }
            ],
            "stdout": "${\n    if (inputs.d){\n        return inputs.file.nameroot;\n    }else{\n        return inputs.file.basename + '.gz';\n    }\n}\n",
            "baseCommand": [
                "gzip",
                "-c"
            ],
            "id": "#gzip.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "HOMER-annotatePeaks",
            "doc": "Software for motif discovery and next generation sequencing analysis",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/homer:4.11--pl526h2bce143_2",
                    "id": "#homer-docker.yml"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "package": "homer",
                            "version": [
                                "4.11"
                            ],
                            "specs": [
                                "https://anaconda.org/bioconda/homer"
                            ]
                        }
                    ],
                    "id": "#homer-bioconda.yml"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-annStats"
                    },
                    "id": "#homer-annotatePeaks.cwl/annStats"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-d"
                    },
                    "id": "#homer-annotatePeaks.cwl/d"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-fpkm"
                    },
                    "id": "#homer-annotatePeaks.cwl/fpkm"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Genome version: hg19, hg38\n",
                    "id": "#homer-annotatePeaks.cwl/genome"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-gff"
                    },
                    "doc": "GFF definition file\n",
                    "id": "#homer-annotatePeaks.cwl/gff"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-gff3"
                    },
                    "doc": "GFF3 definition file\n",
                    "id": "#homer-annotatePeaks.cwl/gff3"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-gtf"
                    },
                    "doc": "GTF definition file\n",
                    "id": "#homer-annotatePeaks.cwl/gtf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Peak/BED file\n",
                    "id": "#homer-annotatePeaks.cwl/input"
                },
                {
                    "type": "string",
                    "id": "#homer-annotatePeaks.cwl/o"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.annStats)"
                    },
                    "id": "#homer-annotatePeaks.cwl/annStats_out"
                },
                {
                    "type": "File",
                    "id": "#homer-annotatePeaks.cwl/output",
                    "outputBinding": {
                        "glob": "$(inputs.o)"
                    }
                }
            ],
            "stdout": "$(inputs.o)",
            "baseCommand": [
                "annotatePeaks.pl"
            ],
            "id": "#homer-annotatePeaks.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "HOMER-makeTagDirectory",
            "doc": "Software for motif discovery and next generation sequencing analysis",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "$import": "#homer-docker.yml"
                },
                {
                    "$import": "#homer-bioconda.yml"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 16,
                        "prefix": "-checkGC"
                    },
                    "doc": "check Sequence bias, requires \"-genome\"\n",
                    "id": "#homer-makeTagDirectory.cwl/checkGC"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "Directory"
                        }
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-d"
                    },
                    "doc": "<tag directory> [tag directory 2] ... (add Tag directory to new tag directory)\n",
                    "id": "#homer-makeTagDirectory.cwl/d"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-flip"
                    },
                    "doc": "flip strand of each read, i.e. might want to use with some RNA-seq\n",
                    "id": "#homer-makeTagDirectory.cwl/flip"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-force5th"
                    },
                    "doc": "(5th column of BED file contains # of reads mapping to position)\n",
                    "id": "#homer-makeTagDirectory.cwl/force5th"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-format"
                    },
                    "doc": "Input file format: BED, SAM, bowtie, etc.\n",
                    "id": "#homer-makeTagDirectory.cwl/format"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-fragLength"
                    },
                    "doc": "Set estimated fragment length or use PE length - given: use read lengths\n",
                    "id": "#homer-makeTagDirectory.cwl/fragLength"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 15,
                        "prefix": "-genome"
                    },
                    "doc": "<path-to-FASTA file or directory of FASTA files>\n",
                    "id": "#homer-makeTagDirectory.cwl/genome"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Input file: BED, SAM, bowtie, etc.\n",
                    "id": "#homer-makeTagDirectory.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "-minlen"
                    },
                    "doc": "<#> and -maxlen <#> (Filter reads with lengths outside this range)\n",
                    "id": "#homer-makeTagDirectory.cwl/minlen"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "-precision"
                    },
                    "doc": "<1|2|3> (number of decimal places to use for tag totals, default: 1)\n",
                    "id": "#homer-makeTagDirectory.cwl/precision"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-single"
                    },
                    "doc": "(Create a single tags.tsv file for all \"chromosomes\" - i.e. if >100 chromosomes)\n",
                    "id": "#homer-makeTagDirectory.cwl/single"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-t"
                    },
                    "doc": "<tag file> [tag file 2] ... (add tag file i.e. *.tags.tsv to new tag directory)\n",
                    "id": "#homer-makeTagDirectory.cwl/t"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Output directory name with tags files\n",
                    "id": "#homer-makeTagDirectory.cwl/tags_directory_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-tbp"
                    },
                    "doc": "<#> (Maximum tags per bp, default: no maximum)\n",
                    "id": "#homer-makeTagDirectory.cwl/tbp"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-totalReads"
                    },
                    "doc": "<#|all|default> (set the effective total number of reads - all includes multimappers)\n",
                    "id": "#homer-makeTagDirectory.cwl/totalReads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-update"
                    },
                    "doc": "(Use current tag directory for QC/processing, do not parse new alignment files)\n",
                    "id": "#homer-makeTagDirectory.cwl/update"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.tags_directory_name)"
                    },
                    "id": "#homer-makeTagDirectory.cwl/tags_directory"
                }
            ],
            "baseCommand": [
                "makeTagDirectory"
            ],
            "id": "#homer-makeTagDirectory.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "igvtools-toTDF",
            "doc": "The igvtools utility provides a set of tools for pre-processing data files",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 2048,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/igvtools:2.5.3--0",
                    "id": "#igvtools-docker.yml"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "package": "igvtools",
                            "version": [
                                "2.5.3"
                            ],
                            "specs": [
                                "https://anaconda.org/bioconda/igvtools"
                            ]
                        }
                    ],
                    "id": "#igvtools-bioconda.yml"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--fileType"
                    },
                    "id": "#igvtools-totdf.cwl/f"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#igvtools-totdf.cwl/g"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#igvtools-totdf.cwl/i"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#igvtools-totdf.cwl/o"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-z"
                    },
                    "id": "#igvtools-totdf.cwl/z"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.o)"
                    },
                    "id": "#igvtools-totdf.cwl/out_tdf"
                }
            ],
            "baseCommand": [
                "igvtools",
                "toTDF"
            ],
            "id": "#igvtools-totdf.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "MACS2-callpeak",
            "doc": "BASH echo command",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/macs2:2.2.7.1--py37h516909a_0",
                    "id": "#macs2-docker.yml"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "package": "macs2",
                            "version": [
                                "2.2.7.1"
                            ],
                            "specs": [
                                "https://anaconda.org/bioconda/macs2"
                            ]
                        }
                    ],
                    "id": "#macs2-bioconda.yml"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bdg"
                    },
                    "doc": "Whether or not to save extended fragment pileup, and local lambda tracks (two files) at every bp into a bedGraph file. DEFAULT: True",
                    "id": "#macs2-callpeak.cwl/B"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--broad"
                    },
                    "doc": "When this flag is on, MACS will try to composite broad regions in BED12\n",
                    "id": "#macs2-callpeak.cwl/broad"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--broad-cutoff"
                    },
                    "doc": "Cutoff for broad region. This option is not available unless --broad is set. If -p is set, this is a pvalue cutoff, otherwise, it's a qvalue cutoff. DEFAULT: 0.1\n",
                    "id": "#macs2-callpeak.cwl/broad-cutoff"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--control"
                    },
                    "doc": "The control or mock data file. Please follow the same direction as for -t/--treatment.\n",
                    "id": "#macs2-callpeak.cwl/c"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--call-summits"
                    },
                    "doc": "If set, MACS will use a more sophisticated signal processing approach to find subpeak summits in each enriched peak region. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/call-summits"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--cutoff-analysis"
                    },
                    "doc": "While set, MACS2 will analyze number or total length of peaks that can be called by different p-value cutoff then output a summary table to help user decide a better cutoff. The table will be saved in NAME_cutoff_analysis.txt file. Note, minlen and maxgap may affect the results. WARNING: May take ~30 folds longer time to finish. DEFAULT: False Post-processing options: ",
                    "id": "#macs2-callpeak.cwl/cutoff-analysis"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--extsize"
                    },
                    "doc": "While '--nomodel' is set, MACS uses this parameter to extend reads in 5'->3' direction to fix-sized fragments\n",
                    "id": "#macs2-callpeak.cwl/extsize"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--format"
                    },
                    "doc": "-f {AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE}, --format {AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE} Format of tag file, \"AUTO\", \"BED\" or \"ELAND\" or \"ELANDMULTI\" or \"ELANDEXPORT\" or \"SAM\" or \"BAM\" or \"BOWTIE\" or \"BAMPE\". The default AUTO option will let MACS decide which format the file is. Note that MACS can't detect \"BAMPE\" or \"BEDPE\" format with \"AUTO\", and you have to implicitly specify the format for \"BAMPE\" and \"BEDPE\". DEFAULT: \"AUTO\".",
                    "id": "#macs2-callpeak.cwl/f"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--gsize"
                    },
                    "doc": "It's the mappable genome size or effective genome size which is defined as the genome size which can be sequenced.\n",
                    "id": "#macs2-callpeak.cwl/g"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--name"
                    },
                    "doc": "The name string of the experiment. MACS will use this string NAME to create output files like\nNAME_peaks.xls, NAME_negative_peaks.xls, NAME_peaks.bed , NAME_summits.bed, NAME_model.r and so\non. So please avoid any confliction between these filenames and your existing files\n",
                    "id": "#macs2-callpeak.cwl/n"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--nomodel"
                    },
                    "doc": "While on, MACS will bypass building the shifting model.\n",
                    "id": "#macs2-callpeak.cwl/nomodel"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--outdir"
                    },
                    "doc": "MACS2 will save all output files into speficied folder for this option\n",
                    "id": "#macs2-callpeak.cwl/outdir_name"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--pvalue"
                    },
                    "doc": "Pvalue cutoff for peak detection. DEFAULT: not set.  -q, and -p are mutually exclusive. If pvalue cutoff is  set, qvalue will not be calculated and reported as -1  in the final .xls file..",
                    "id": "#macs2-callpeak.cwl/p"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--pvalue",
                        "loadContents": true,
                        "valueFrom": "${ return inputs.input.contents.split('\\n')[0];}"
                    },
                    "doc": "Pvalue cutoff for peak detection loaded from the first line of a file.\n",
                    "id": "#macs2-callpeak.cwl/p_file"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--qvalue"
                    },
                    "doc": "The qvalue (minimum FDR) cutoff to call significant regions. Default is 0.05\n",
                    "id": "#macs2-callpeak.cwl/q"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--qvalue",
                        "loadContents": true,
                        "valueFrom": "${ return inputs.q_file.contents.split('\\n')[0];}"
                    },
                    "doc": "The qvalue (minimum FDR) cutoff to call significant regions loaded from the first line of a file. Default is 0.05\n",
                    "id": "#macs2-callpeak.cwl/q_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--shift"
                    },
                    "doc": "Note, this is NOT the legacy --shiftsize option which is replaced by --extsize! You can set an arbitrary shift in bp here.\n",
                    "id": "#macs2-callpeak.cwl/shift"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--treatment"
                    },
                    "doc": "Treatment sample file(s). If multiple files are given as -t A B C, then they will all be read and pooled together. IMPORTANT: the first sample will be used as the outputs basename.",
                    "id": "#macs2-callpeak.cwl/t"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outdir_name)/$(inputs.n)_summits.bed"
                    },
                    "id": "#macs2-callpeak.cwl/bed"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.outdir_name)/$(inputs.n)_cutoff_analysis.txt"
                    },
                    "id": "#macs2-callpeak.cwl/cutoff_analysis"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.outdir_name)/$(inputs.n)_cutoff_analysis_inflection.txt"
                    },
                    "id": "#macs2-callpeak.cwl/cutoff_analysis_inflection"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.outdir_name)/$(inputs.n)_cutoff_analysis.pdf"
                    },
                    "id": "#macs2-callpeak.cwl/cutoff_analysis_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outdir_name)/$(inputs.n)_control_lambda.bdg"
                    },
                    "id": "#macs2-callpeak.cwl/lambda"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outdir_name)/$(inputs.n)_peaks.narrowPeak"
                    },
                    "id": "#macs2-callpeak.cwl/narrowPeak"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outdir_name)/$(inputs.n)_treat_pileup.bdg"
                    },
                    "id": "#macs2-callpeak.cwl/pileup"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outdir_name)/$(inputs.n)_peaks.xls"
                    },
                    "id": "#macs2-callpeak.cwl/xls"
                }
            ],
            "baseCommand": [
                "macs2",
                "callpeak"
            ],
            "id": "#macs2-callpeak.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "ChIP-seq peak caller workflow MACS2 based",
            "doc": "This workflow execute peak caller and QC for ChIP-seq using MACS2",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/extsize"
                },
                {
                    "type": "File",
                    "id": "#main/genome_fasta"
                },
                {
                    "type": "File",
                    "id": "#main/genome_gtf"
                },
                {
                    "type": "string",
                    "id": "#main/genome_name"
                },
                {
                    "type": "string",
                    "id": "#main/macs_callpeaks_g"
                },
                {
                    "type": "float",
                    "id": "#main/macs_callpeaks_q"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/nomodel"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/tagAlign_gz"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#main/homer_annotate_peaks/annStats_out",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#main/homer_annotate_peaks_annStats"
                },
                {
                    "outputSource": "#main/homer_annotate_peaks/output",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/homer_annotate_peaks_output"
                },
                {
                    "outputSource": "#main/lambda_bdg_to_tdf/out_tdf",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/lambda_tdf_out"
                },
                {
                    "outputSource": "#main/macs_callpeak_q_value/bed",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/macs_callpeak_q_value_bed"
                },
                {
                    "outputSource": "#main/macs_callpeak_q_value/narrowPeak",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/macs_callpeak_q_value_narrowPeak"
                },
                {
                    "outputSource": "#main/macs_callpeak_q_value/xls",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/macs_callpeak_q_value_xls"
                },
                {
                    "outputSource": "#main/macs_cutoff/out_inflection",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/macs_cutoff_inflection"
                },
                {
                    "outputSource": "#main/macs_cutoff/out_pdf",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/macs_cutoff_pdf"
                },
                {
                    "outputSource": "#main/pileup_bdg_to_tdf/out_tdf",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/pileup_tdf_out"
                },
                {
                    "outputSource": "#main/readQC/plots",
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#main/readQC_plots"
                }
            ],
            "steps": [
                {
                    "run": "#gzip.cwl",
                    "scatter": "#main/gzip_cat/file",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/gzip_cat/d"
                        },
                        {
                            "source": "#main/tagAlign_gz",
                            "id": "#main/gzip_cat/file"
                        }
                    ],
                    "out": [
                        "#main/gzip_cat/output"
                    ],
                    "id": "#main/gzip_cat"
                },
                {
                    "run": "#homer-annotatePeaks.cwl",
                    "scatter": [
                        "#main/homer_annotate_peaks/input",
                        "#main/homer_annotate_peaks/d"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "valueFrom": "${ return inputs.input.nameroot + \"_annStats.txt\";}",
                            "id": "#main/homer_annotate_peaks/annStats"
                        },
                        {
                            "source": "#main/homer_tags/tags_directory",
                            "id": "#main/homer_annotate_peaks/d"
                        },
                        {
                            "default": true,
                            "id": "#main/homer_annotate_peaks/fpkm"
                        },
                        {
                            "source": "#main/genome_fasta",
                            "id": "#main/homer_annotate_peaks/genome"
                        },
                        {
                            "source": "#main/genome_gtf",
                            "id": "#main/homer_annotate_peaks/gtf"
                        },
                        {
                            "source": "#main/macs_callpeak_q_value/narrowPeak",
                            "id": "#main/homer_annotate_peaks/input"
                        },
                        {
                            "valueFrom": "${ return inputs.input.nameroot + \"_annotation.txt\";}",
                            "id": "#main/homer_annotate_peaks/o"
                        }
                    ],
                    "out": [
                        "#main/homer_annotate_peaks/output",
                        "#main/homer_annotate_peaks/annStats_out"
                    ],
                    "id": "#main/homer_annotate_peaks"
                },
                {
                    "run": "#homer-makeTagDirectory.cwl",
                    "scatter": "#main/homer_tags/input",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/homer_tags/checkGC"
                        },
                        {
                            "default": "bed",
                            "id": "#main/homer_tags/format"
                        },
                        {
                            "source": "#main/genome_fasta",
                            "id": "#main/homer_tags/genome"
                        },
                        {
                            "source": "#main/gzip_cat/output",
                            "id": "#main/homer_tags/input"
                        },
                        {
                            "valueFrom": "${ return inputs.input.nameroot + \"_tags\";}",
                            "id": "#main/homer_tags/tags_directory_name"
                        }
                    ],
                    "out": [
                        "#main/homer_tags/tags_directory"
                    ],
                    "id": "#main/homer_tags"
                },
                {
                    "run": "#igvtools-totdf.cwl",
                    "scatter": "#main/lambda_bdg_to_tdf/i",
                    "in": [
                        {
                            "source": "#main/genome_name",
                            "id": "#main/lambda_bdg_to_tdf/g"
                        },
                        {
                            "source": "#main/macs_callpeak_q_value/lambda",
                            "id": "#main/lambda_bdg_to_tdf/i"
                        },
                        {
                            "valueFrom": "${ return inputs.i.nameroot + \".tdf\";}",
                            "id": "#main/lambda_bdg_to_tdf/o"
                        },
                        {
                            "default": 5,
                            "id": "#main/lambda_bdg_to_tdf/z"
                        }
                    ],
                    "out": [
                        "#main/lambda_bdg_to_tdf/out_tdf"
                    ],
                    "id": "#main/lambda_bdg_to_tdf"
                },
                {
                    "run": "#macs2-callpeak.cwl",
                    "scatter": "#main/macs_callpeak/t",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/macs_callpeak/B"
                        },
                        {
                            "default": true,
                            "id": "#main/macs_callpeak/cutoff-analysis"
                        },
                        {
                            "source": "#main/extsize",
                            "id": "#main/macs_callpeak/extsize"
                        },
                        {
                            "default": "BED",
                            "id": "#main/macs_callpeak/f"
                        },
                        {
                            "source": "#main/macs_callpeaks_g",
                            "id": "#main/macs_callpeak/g"
                        },
                        {
                            "valueFrom": "${ return inputs.t.nameroot;}",
                            "id": "#main/macs_callpeak/n"
                        },
                        {
                            "source": "#main/nomodel",
                            "id": "#main/macs_callpeak/nomodel"
                        },
                        {
                            "valueFrom": "${ return inputs.t.nameroot + \"_peaks\";}",
                            "id": "#main/macs_callpeak/outdir_name"
                        },
                        {
                            "source": "#main/macs_callpeaks_q",
                            "id": "#main/macs_callpeak/q"
                        },
                        {
                            "default": 0,
                            "id": "#main/macs_callpeak/shift"
                        },
                        {
                            "source": "#main/gzip_cat/output",
                            "id": "#main/macs_callpeak/t"
                        }
                    ],
                    "out": [
                        "#main/macs_callpeak/cutoff_analysis"
                    ],
                    "id": "#main/macs_callpeak"
                },
                {
                    "run": "#macs2-callpeak.cwl",
                    "scatter": [
                        "#main/macs_callpeak_q_value/t",
                        "#main/macs_callpeak_q_value/q_file"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/macs_callpeak_q_value/B"
                        },
                        {
                            "default": true,
                            "id": "#main/macs_callpeak_q_value/call-summits"
                        },
                        {
                            "default": true,
                            "id": "#main/macs_callpeak_q_value/cutoff-analysis"
                        },
                        {
                            "source": "#main/extsize",
                            "id": "#main/macs_callpeak_q_value/extsize"
                        },
                        {
                            "default": "BED",
                            "id": "#main/macs_callpeak_q_value/f"
                        },
                        {
                            "source": "#main/macs_callpeaks_g",
                            "id": "#main/macs_callpeak_q_value/g"
                        },
                        {
                            "valueFrom": "${ return inputs.t.nameroot;}",
                            "id": "#main/macs_callpeak_q_value/n"
                        },
                        {
                            "source": "#main/nomodel",
                            "id": "#main/macs_callpeak_q_value/nomodel"
                        },
                        {
                            "valueFrom": "${ return inputs.t.nameroot + \"_peaks\";}",
                            "id": "#main/macs_callpeak_q_value/outdir_name"
                        },
                        {
                            "source": "#main/macs_cutoff/out_inflection",
                            "id": "#main/macs_callpeak_q_value/q_file"
                        },
                        {
                            "default": 0,
                            "id": "#main/macs_callpeak_q_value/shift"
                        },
                        {
                            "source": "#main/gzip_cat/output",
                            "id": "#main/macs_callpeak_q_value/t"
                        }
                    ],
                    "out": [
                        "#main/macs_callpeak_q_value/lambda",
                        "#main/macs_callpeak_q_value/pileup",
                        "#main/macs_callpeak_q_value/narrowPeak",
                        "#main/macs_callpeak_q_value/xls",
                        "#main/macs_callpeak_q_value/bed"
                    ],
                    "id": "#main/macs_callpeak_q_value"
                },
                {
                    "run": "#macs-cutoff.cwl",
                    "scatter": "#main/macs_cutoff/peak_cutoff_file",
                    "in": [
                        {
                            "valueFrom": "${ return inputs.peak_cutoff_file.nameroot + \"_inflection.txt\";}",
                            "id": "#main/macs_cutoff/out_inflection_name"
                        },
                        {
                            "valueFrom": "${ return inputs.peak_cutoff_file.nameroot + \".pdf\";}",
                            "id": "#main/macs_cutoff/out_pdf_name"
                        },
                        {
                            "source": "#main/macs_callpeak/cutoff_analysis",
                            "id": "#main/macs_cutoff/peak_cutoff_file"
                        }
                    ],
                    "out": [
                        "#main/macs_cutoff/out_pdf",
                        "#main/macs_cutoff/out_inflection"
                    ],
                    "id": "#main/macs_cutoff"
                },
                {
                    "run": "#igvtools-totdf.cwl",
                    "scatter": "#main/pileup_bdg_to_tdf/i",
                    "in": [
                        {
                            "source": "#main/genome_name",
                            "id": "#main/pileup_bdg_to_tdf/g"
                        },
                        {
                            "source": "#main/macs_callpeak_q_value/pileup",
                            "id": "#main/pileup_bdg_to_tdf/i"
                        },
                        {
                            "valueFrom": "${ return inputs.i.nameroot + \".tdf\";}",
                            "id": "#main/pileup_bdg_to_tdf/o"
                        },
                        {
                            "default": 5,
                            "id": "#main/pileup_bdg_to_tdf/z"
                        }
                    ],
                    "out": [
                        "#main/pileup_bdg_to_tdf/out_tdf"
                    ],
                    "id": "#main/pileup_bdg_to_tdf"
                },
                {
                    "run": "#readQC.cwl",
                    "scatter": "#main/readQC/tags_directory",
                    "in": [
                        {
                            "source": "#main/homer_tags/tags_directory",
                            "id": "#main/readQC/tags_directory"
                        }
                    ],
                    "out": [
                        "#main/readQC/plots"
                    ],
                    "id": "#main/readQC"
                }
            ],
            "id": "#main",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
